@@ -35,6 +35,14 @@ class StructMeta(type):
 
         clsobj = super().__new__(cls, clsname, bases, dict(clsdict))
 
+        if len(bases) > 1:
+            clsobj._parameters = []
+            for base in bases:
+                try:
+                    clsobj._parameters += base._parameters
+                except AttributeError:
+                    pass
+
         sig = make_signature(fields)
         setattr(clsobj, '__signature__', sig)
 
@@ -90,7 +98,7 @@ def frozen_attributes(cls):
     def frozensetattr(self, key, value):
         if self._is_frozen and not hasattr(self, key):
             raise AttributeError(
-                "{} object has no attribute {}".format(cls.__name__, key)
+                f"{cls.__name__} object has no attribute {key}"
             )
         else:
             object.__setattr__(self, key, value)
