@@ -8,7 +8,7 @@ class ParametersGroup(Structure):
     Attributes
     ----------
     _parameters : List of strings
-        List of paramters to be exported.
+        List of parameters to be exported.
 
     See Also
     --------
@@ -43,6 +43,9 @@ class ParametersGroup(Structure):
             if value is not None:
                 setattr(self, param, value)
 
+    def __repr__(self):
+        return str(self.to_dict())
+
 
 class ParameterWrapper(ParametersGroup):
     """Base class for converting the config from objects such as units.
@@ -70,7 +73,7 @@ class ParameterWrapper(ParametersGroup):
 
     def __init__(self, wrapped_object):
         if not isinstance(wrapped_object, self._baseClass):
-            raise CADETProcessError("Expected {}".format(self._baseClass))
+            raise CADETProcessError(f"Expected {self._baseClass}")
 
         model = wrapped_object.model
         try:
