@@ -9,6 +9,7 @@ from CADETProcess.dataStructure import String, UnsignedInteger
 from CADETProcess.processModel import FlowSheet, Process
 from CADETProcess.processModel import Cstr, Source, Sink
 
+
 class CompartmentBuilder(metaclass=StructMeta):
     name = String()
     n_compartments = UnsignedInteger()
@@ -20,8 +21,7 @@ class CompartmentBuilder(metaclass=StructMeta):
             binding_model=None,
             bulk_reaction_model=None,
             particle_reaction_model=None,
-            name=None,
-        ):
+            name=None):
         """Initialize builder.
 
         Parameters
@@ -121,7 +121,8 @@ class CompartmentBuilder(metaclass=StructMeta):
     @wraps(Cstr.particle_reaction_model)
     def particle_reaction_model(self, particle_reaction_model):
         if particle_reaction_model is not None:
-            self._compartment_model.particle_reaction_model = particle_reaction_model
+            self._compartment_model.particle_reaction_model \
+                = particle_reaction_model
 
             for compartment in self._real_compartments:
                 compartment.particle_reaction_model = particle_reaction_model
@@ -236,7 +237,7 @@ class CompartmentBuilder(metaclass=StructMeta):
             if not isinstance(compartment, Sink):
                 compartment.c = init_c[i, :].tolist()
 
-    def add_tracer(self, compartment_index, c, t_inj, flow_rate, t_start=0):
+    def add_tracer(self, compartment_index, c, t_inj, flow_rate, t_start=0, flow_rate_filter=True):
         """Add tracer injection to compartment model.
 
         For this purpose, a new inlet source is instantiated and connected to
@@ -255,6 +256,9 @@ class CompartmentBuilder(metaclass=StructMeta):
             flow rate during injection.
         t_start : float, optional
             Time at which injection starts. The default is 0.
+        flow_rate_filter : bool, optional
+            If True, the compartment volume is kept constant by adding a flow rate filter.
+            The default is True.
 
         Raises
         ------
@@ -269,7 +273,8 @@ class CompartmentBuilder(metaclass=StructMeta):
         if compartment_unit not in self._real_compartments:
             raise CADETProcessError("Tracer must connect to real compartment")
 
-        compartment_unit.flow_rate_filter = flow_rate
+        if flow_rate_filter:
+            compartment_unit.flow_rate_filter = flow_rate
 
         self.flow_sheet.add_unit(tracer)
         self.flow_sheet.add_connection(tracer, compartment_unit)
@@ -293,6 +298,7 @@ class CompartmentBuilder(metaclass=StructMeta):
                     f"Unbalanced flow rate for compartment '{comp.name}'."
                 )
 
+
 class CompartmentModel(Cstr):
     """Dummy Class for checking binding and reaction models"""
     pass
